==> gbsite-1.1.0.tar.gz: gbsite/templates/gb/gb_mktginfopage.php <==
     <!-- the content area -->
      <table cellpadding="0" cellspacing="0" border="0" width="453">
        <tr>
          <td width="433"><!-- <img src="<?= $image_path ?>/home_header.gif" width=431 height=84 alt="" border="0"> --></td>          
        </tr>
        <tr>
          <!-- content area -->
          <td width="433">           
            <!-- <img src="<?= $image_path ?>/shim.gif" width=433 height=30 alt="" border="0"> -->

<? if(!empty($context)) { ?>
<font face="<?= $font_1 ?>" color="<?= $color_6 ?>"><H3><b><?= $context ?></b></H3></font><p>
<? while(list(,$ce) = @each($context_error)) {?>
<p><?= $ce ?>
<? } 
  } else { ?>
            <a href="/genpage?pgbook"><img align="right" border="0" hspace="4" src="<?= $image_path ?>/pgsqlbook_small.gif" width="150" height="171" alt="PostgreSQL: Introduction and Concepts - Click here to buy online!"></a><font face="<?= $font_1 ?>" color="<?= $color_6 ?>"><b>Thanks for Your <br>Interest in Great Bridge PostgreSQL.</b></font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">
<p>Great Bridge is proud to offer a suite of professional products and
solutions based on PostgreSQL, including certified software releases,
technical support, consulting services, and training. You can learn more
about Great Bridge PostgreSQL by exploring our web site.

<p>We're excited that you are interested in the power of Great Bridge
PostgreSQL. We would also like to hear more about your needs and inform you
of our progress. Take a moment to provide us with some information and your
comments below. Rest assured that we won't share your information with
anyone else.</font>
<? } ?>
<p>
<?
    $mktg_code = "groot1";
    if(!empty($context)) $send_to = "/docview/$doc/";
    include("mktg_survey.php");
 ?>
          </td>
        </tr>
      </table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/gb/gb_mktginfopage.php <==
     <!-- the content area -->
      <table cellpadding="0" cellspacing="0" border="0" width="453">
        <tr>
          <td width="433"><!-- <img src="<?= $image_path ?>/home_header.gif" width=431 height=84 alt="" border="0"> --></td>          
        </tr>
        <tr>
          <!-- content area -->
          <td width="433">           
            <!-- <img src="<?= $image_path ?>/shim.gif" width=433 height=30 alt="" border="0"> -->

<? if(!empty($context)) { ?>
<font face="<?= $font_1 ?>" color="<?= $color_6 ?>"><H3><b><?= $context ?></b></H3></font><p>
<? while(list(,$ce) = @each($context_error)) {?>
<p><font face="<?= $font_1 ?>" color="<?= $color_1 ?>" size="2"><?= $ce ?></font>
<? } 
  } else { ?>
            <a href="/genpage?pgbook"><img align="right" border="0" hspace="4" src="<?= $image_path ?>/pgsqlbook_small.gif" width="150" height="171" alt="PostgreSQL: Introduction and Concepts - Click here to buy online!"></a><font face="<?= $font_1 ?>" color="<?= $color_6 ?>"><b>Thanks for Your <br>Interest in Great Bridge PostgreSQL.</b></font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">
<p>Great Bridge is proud to offer a suite of professional products and
solutions based on PostgreSQL, including certified software releases,
technical support, consulting services, and training. You can learn more
about Great Bridge PostgreSQL by exploring our web site.

<p>We're excited that you are interested in the power of Great Bridge
PostgreSQL. We would also like to hear more about your needs and inform you
of our progress. Take a moment to provide us with some information and your
comments below. Rest assured that we won't share your information with
anyone else.</font>
<? } ?>
<p>
<?
    $mktg_code = "groot1";
    if(!empty($context)) $send_to = "/docview". $PATH_INFO . (!empty($QUERY_STRING)?"?$QUERY_STRING":"");
    include("mktg_survey.php");
 ?>
          </td>
        </tr>
      </table>
